==> react-redux-form-0.13.6.tgz: package/src/reducers/model-reducer.js <==
import _get from '../utils/get';
import icepick from 'icepick';
import arraysEqual from '../utils/arrays-equal';
import toPath from '../utils/to-path';

import actionTypes from '../action-types';

function icepickSet(state, path, value) {
  return icepick.setIn(state, path, value);
}

function createModeler(getter = _get, setter = icepickSet, initialModelState = {}) {
  return function _createModelReducer(model, initialState = initialModelState) {
    const modelPath = toPath(model);

    const modelReducer = (state = initialState, action) => {
      if (!action.model) {
        return state;
      }

      const path = toPath(action.model);

      if (!arraysEqual(path.slice(0, modelPath.length), modelPath)) {
        return state;
      }

      const localPath = path.slice(modelPath.length);

      switch (action.type) {
        case actionTypes.BATCH:
          return action.actions.reduce(modelReducer, state);

        case actionTypes.CHANGE:
        case actionTypes.LOAD:
          if (!localPath.length) {
            return action.value;
          }

          if (getter(state, localPath) === action.value) {
            return state;
          }

          return setter(state, localPath, action.value);

        case actionTypes.RESET:
          if (!localPath.length) {
            return initialState;
          }

          if (getter(state, localPath) === getter(initialState, localPath)) {
            return state;
          }

          return setter(
            state,
            localPath,
            getter(initialState, localPath)
          );

        default:
          return state;
      }
    };

    return modelReducer;
  };
}

const modelReducer = createModeler();

function createModelReducer(...args) {
  console.warn('The createModelReducer() function is deprecated (renamed). '
    + 'Please use modelReducer().');

  return modelReducer(...args);
}

export {
  createModeler,
  createModelReducer,
};
export default modelReducer;

==> react-redux-form-1.0.4.tgz: package/src/reducers/model-reducer.js <==
import _get from '../utils/get';
import i from 'icepick';
import arraysEqual from '../utils/arrays-equal';
import toPath from '../utils/to-path';

import actionTypes from '../action-types';
import createBatchReducer from '../enhancers/batched-enhancer';

function icepickSet(state, path, value) {
  return i.setIn(state, path, value);
}

const defaultStrategy = {
  get: _get,
  set: icepickSet,
  object: {},
};

function createModeler(strategy = defaultStrategy) {
  const {
    get: getter,
    set: setter,
    object,
  } = strategy;

  return function _createModelReducer(model, initialState = object) {
    const modelPath = toPath(model);

    const modelReducer = (state = initialState, action) => {
      if (!action.model) {
        return state;
      }

      const path = toPath(action.model);

      if (!arraysEqual(path.slice(0, modelPath.length), modelPath)) {
        return state;
      }

      const localPath = path.slice(modelPath.length);

      switch (action.type) {
        case actionTypes.CHANGE:
        case actionTypes.LOAD:
          if (!localPath.length) {
            return action.value;
          }

          if (getter(state, localPath) === action.value) {
            return state;
          }

          return setter(state, localPath, action.value);

        case actionTypes.RESET:
          if (!localPath.length) {
            return initialState;
          }

          if (getter(state, localPath) === getter(initialState, localPath)) {
            return state;
          }

          return setter(
            state,
            localPath,
            getter(initialState, localPath)
          );

        default:
          return state;
      }
    };

    return createBatchReducer(modelReducer, initialState);
  };
}

const modelReducer = createModeler();

export {
  createModeler,
};
export default modelReducer;
